@@ -176,17 +176,22 @@ class OpenEphysBase(object):
 		pass
 
 	def loadKilo(self, **kwargs):
+		import os
 		if 'pname' in kwargs:
 			pname = kwargs['pname']
 		else:
 			pname = self.pname_root
 		# Loads a kilosort session
-		kilodata = KiloSortSession(pname) # pname_root gets walked through and over-written with correct location of kiolsort data
-		if kilodata.load():
-			try:
-				kilodata.removeKSNoiseClusters()
-			except:
-				pass
+		kilodata = None
+		if pname is not None:
+			if os.path.exists(pname):
+				kilodata = KiloSortSession(pname) # pname_root gets walked through and over-written with correct location of kiolsort data
+		if kilodata is not None:
+			if kilodata.load():
+				try:
+					kilodata.removeKSNoiseClusters()
+				except:
+					pass
 		self.kilodata = kilodata
 
 	def __loadSettings__(self):
@@ -232,12 +237,12 @@ class OpenEphysBase(object):
 		self.__loadSettings__()
 		xy, hdir = posProcessor.postprocesspos(self.settings.tracker_params)
 		self.hdir = hdir
-		spk_times = (self.kilodata.spk_times.T / 3e4) + self.recording_start_time
-		if 'plot_type' in kwargs:
+		spk_times = (self.kilodata.spk_times.T / 3e4)
+		if 'plot_type' in kwargs.keys():
 			plot_type = kwargs['plot_type']
 		else:
 			plot_type = 'map'
-		mapiter = MapCalcsGeneric(xy, np.squeeze(hdir), posProcessor.speed, self.xyTS, spk_times, plot_type, **kwargs)
+		mapiter = MapCalcsGeneric(xy, np.squeeze(hdir), posProcessor.speed, self.xyTS, spk_times, plot_type=plot_type, **kwargs)
 		if 'cluster' in kwargs:
 			if type(kwargs['cluster']) == int:
 				mapiter.good_clusters = np.intersect1d([kwargs['cluster']], self.kilodata.good_clusters)
@@ -250,61 +255,7 @@ class OpenEphysBase(object):
 		self.mapiter = mapiter
 		return mapiter
 
-	def plotXCorrs(self, **kwargs):
-		if self.kilodata is None:
-			self.loadKilo(**kwargs)
-		from ephysiopy.common.ephys_generic import SpikeCalcsGeneric
-		corriter = SpikeCalcsGeneric(self.kilodata.spk_times)
-		corriter.spk_clusters = self.kilodata.spk_clusters
-		clusts2plot = []
-		if 'cluster' in kwargs:
-			clusts2plot = np.intersect1d(kwargs['cluster'], self.kilodata.good_clusters)
-		else:
-			clusts2plot = self.kilodata.good_clusters
-		corriter.plotAllXCorrs(clusters=clusts2plot)
-
-	def plotPos(self, jumpmax=None, show=True, **kwargs):
-		"""
-		Plots x vs y position for the current trial
-
-		Parameters
-		----------
-		jumpmax : int
-			The max amount the LED is allowed to instantaneously move
-		show : bool
-			Whether to plot the pos into a figure window or not (default True)
-
-		Returns
-		----------
-		xy : array_like
-			positional data following post-processing
-		"""
-		if jumpmax is None:
-			jumpmax = self.jumpmax
-		import matplotlib.pylab as plt
-		from ephysiopy.common.ephys_generic import PosCalcsGeneric
-
-		self.__loadSettings__()
-		if self.xy is None:
-			self.__loaddata__(**kwargs)
-		posProcessor = PosCalcsGeneric(self.xy[:,0], self.xy[:,1], ppm=300, cm=True, jumpmax=jumpmax)
-		xy, hdir = posProcessor.postprocesspos(self.settings.tracker_params)
-		self.hdir = hdir
-		if 'saveas' in kwargs:
-			saveas = kwargs['saveas']
-			plt.plot(xy[0], xy[1])
-			plt.gca().invert_yaxis()
-			plt.axis('off')
-			plt.savefig(saveas)
-		if show:
-			plt.plot(xy[0], xy[1])
-			plt.gca().invert_yaxis()
-			ax = plt.gca()
-			plt.show()
-			return ax, xy
-		return xy
-
-	def plotMaps(self, plot_type='map', **kwargs):
+	def plotMaps(self, **kwargs):
 		"""
 		Parameters
 		------------
@@ -369,13 +320,14 @@ class OpenEphysBase(object):
 			ppm = 400
 		from ephysiopy.common.ephys_generic import PosCalcsGeneric, MapCalcsGeneric
 		if self.xy is None:
+
 			self.__loaddata__(**kwargs)
 		posProcessor = PosCalcsGeneric(self.xy[:,0], self.xy[:,1], ppm, jumpmax=self.jumpmax)
 		import os
 		self.__loadSettings__()
 		xy, hdir = posProcessor.postprocesspos(self.settings.tracker_params)
 		self.hdir = hdir
-		spk_times = (self.kilodata.spk_times.T / 3e4) + self.recording_start_time
+		spk_times = (self.kilodata.spk_times.T / 3e4)
 		mapiter = MapCalcsGeneric(xy, np.squeeze(hdir), posProcessor.speed, self.xyTS, spk_times, plot_type, **kwargs)
 		if 'clusters' in kwargs:
 			if type(kwargs['clusters']) == int:
@@ -389,6 +341,60 @@ class OpenEphysBase(object):
 		self.mapiter = mapiter
 		[ print("") for cluster in mapiter ]
 
+	def plotXCorrs(self, **kwargs):
+		if self.kilodata is None:
+			self.loadKilo(**kwargs)
+		from ephysiopy.common.ephys_generic import SpikeCalcsGeneric
+		corriter = SpikeCalcsGeneric(self.kilodata.spk_times)
+		corriter.spk_clusters = self.kilodata.spk_clusters
+		clusts2plot = []
+		if 'cluster' in kwargs:
+			clusts2plot = np.intersect1d(kwargs['cluster'], self.kilodata.good_clusters)
+		else:
+			clusts2plot = self.kilodata.good_clusters
+		corriter.plotAllXCorrs(clusters=clusts2plot)
+
+	def plotPos(self, jumpmax=None, show=True, **kwargs):
+		"""
+		Plots x vs y position for the current trial
+
+		Parameters
+		----------
+		jumpmax : int
+			The max amount the LED is allowed to instantaneously move
+		show : bool
+			Whether to plot the pos into a figure window or not (default True)
+
+		Returns
+		----------
+		xy : array_like
+			positional data following post-processing
+		"""
+		if jumpmax is None:
+			jumpmax = self.jumpmax
+		import matplotlib.pylab as plt
+		from ephysiopy.common.ephys_generic import PosCalcsGeneric
+
+		self.__loadSettings__()
+		if self.xy is None:
+			self.__loaddata__(**kwargs)
+		posProcessor = PosCalcsGeneric(self.xy[:,0], self.xy[:,1], ppm=300, cm=True, jumpmax=jumpmax)
+		xy, hdir = posProcessor.postprocesspos(self.settings.tracker_params)
+		self.hdir = hdir
+		if 'saveas' in kwargs:
+			saveas = kwargs['saveas']
+			plt.plot(xy[0], xy[1])
+			plt.gca().invert_yaxis()
+			plt.axis('off')
+			plt.savefig(saveas)
+		if show:
+			plt.plot(xy[0], xy[1])
+			plt.gca().invert_yaxis()
+			ax = plt.gca()
+			plt.show()
+			return ax, xy
+		return xy
+
 	def plotEEGPower(self, channel=0):
 		"""
 		Plots LFP power
@@ -727,7 +733,10 @@ class OpenEphysNPX(OpenEphysBase):
 		plt.show()
 
 	def loadKilo(self, **kwargs):
-		super().loadKilo(pname=self.path2APdata)
+		if self.path2APdata is not None:
+			super().loadKilo(pname=self.path2APdata)
+		else:
+			super().loadKilo(**kwargs)
 
 	def plotPos(self, jumpmax=None, show=True, **kwargs):
 		super().plotPos(jumpmax, show, **kwargs)
